@@ -1,6 +1,6 @@
 from StructNoSQL.dynamodb.dynamodb_core import PrimaryIndex, GlobalSecondaryIndex
 from StructNoSQL.fields import BaseField, MapModel, MapField, TableDataModel
-from StructNoSQL.table import BaseTable
+from StructNoSQL.tables import BaseTable, BasicTable, CachingTable
 from StructNoSQL.validator import NoneType, ActiveSelf
 from StructNoSQL.dynamodb.models import FieldGetter, FieldSetter, UnsafeFieldSetter, FieldRemover
 from StructNoSQL.exceptions import *
