@@ -355,7 +355,7 @@ class DynamoDbCoreAdapter:
             'ExpressionAttributeNames': expression_attribute_names_dict,
         }
         response = self._execute_update_query(query_kwargs_dict=update_query_kwargs)
-        if response.attributes is not None:
+        if response is not None and response.attributes is not None:
             response.attributes = Utils.dynamodb_to_python_higher_level(response.attributes)
         return response
 
@@ -365,42 +365,65 @@ class DynamoDbCoreAdapter:
     ) -> Optional[Response]:
 
         current_path_target = ""
+        current_path_element: Optional[DatabasePathElement] = None
+        current_item_default_value: Any = None
         expression_attribute_names_dict: Dict[str, str] = dict()
         last_response: Optional[Response] = None
 
-        for i, path_element in enumerate(field_path_elements):
+        for i, current_path_element in enumerate(field_path_elements):
+            is_last_path_element = i >= (len(field_path_elements) - 1)
             if i > 0:
                 current_path_target += "."
 
             if i + 1 >= len(field_path_elements) and last_item_custom_overriding_init_value is not None:
-                item_default_value = last_item_custom_overriding_init_value
+                current_item_default_value = last_item_custom_overriding_init_value
             else:
-                item_default_value = path_element.get_default_value()
+                current_item_default_value = current_path_element.get_default_value()
 
             current_path_key = f"#pathKey{i}"
             current_path_target += current_path_key
-            expression_attribute_names_dict[current_path_key] = path_element.element_key
+            expression_attribute_names_dict[current_path_key] = current_path_element.element_key
 
             current_update_expression = f"SET {current_path_target} = if_not_exists({current_path_target}, :item)"
             current_set_potentially_missing_object_query_kwargs = {
                 "TableName": self.table_name,
                 "Key": {index_name: key_value},
-                "ReturnValues": "UPDATED_NEW",
+                "ReturnValues": "UPDATED_NEW" if is_last_path_element else "NONE",
+                # We do not need to waste retrieving the UPDATED_NEW value when we know we we
+                # will it only for the last path element (we use right after the loop ended)
                 "UpdateExpression": current_update_expression,
                 "ExpressionAttributeNames": expression_attribute_names_dict,
                 "ExpressionAttributeValues": {
-                    ":item": item_default_value
+                    ":item": current_item_default_value
                 }
             }
             last_response = self._execute_update_query(query_kwargs_dict=current_set_potentially_missing_object_query_kwargs)
+
+        if current_path_element is not None:
+            # If the last item attribute value in the database does (retrieved thanks to the "UPDATED_NEW" ReturnValues),
+            # do not equal its default_value (which is either the field type default value, or the
+            # last_item_custom_overriding_init_value parameter), we want to initialize again the item, because this means
+            # that the attribute existed, so the SET update expression with if_not_exists did not performed, and we do
+            # not currently have the value we want in the database. We perform this operation only for the last path
+            # element in the request, to avoid overriding and scratching list or dictionary that are expected to exist.
+            field_existing_attribute_in_database = last_response.attributes.get(current_path_element.element_key)
+            if field_existing_attribute_in_database != current_item_default_value:
+                # It is possible for the field to already exist, and yet, to not have
+                initialization_response = self._set_update_data_element_to_map_without_default_initialization(
+                    index_name=index_name, key_value=key_value,
+                    field_path_elements=field_path_elements,
+                    value=last_item_custom_overriding_init_value
+                )
+                return initialization_response
         return last_response
 
-    def set_update_data_element_to_map(self, index_name: str, key_value: Any, value: Any,
-                                       field_path_elements: List[DatabasePathElement]) -> Optional[Response]:
+    def _set_update_data_element_to_map_without_default_initialization(
+            self, index_name: str, key_value: Any, field_path_elements: List[DatabasePathElement], value: Any
+    ) -> Optional[Response]:
+
         expression_attribute_names_dict = dict()
         update_expression = "SET "
 
-        last_item_custom_overriding_init_value = None
         for i, path_element in enumerate(field_path_elements):
             current_path_key = f"#pathKey{i}"
             update_expression += current_path_key
@@ -409,7 +432,6 @@ class DynamoDbCoreAdapter:
                 update_expression += "."
             else:
                 update_expression += " = :item"
-                last_item_custom_overriding_init_value = value
 
         update_query_kwargs = {
             "TableName": self.table_name,
@@ -421,7 +443,15 @@ class DynamoDbCoreAdapter:
                 ":item": value
             }
         }
-        response = self._execute_update_query(query_kwargs_dict=update_query_kwargs)
+        return self._execute_update_query(query_kwargs_dict=update_query_kwargs)
+
+    def set_update_data_element_to_map(
+            self, index_name: str, key_value: Any, value: Any, field_path_elements: List[DatabasePathElement]
+    ) -> Optional[Response]:
+
+        response = self._set_update_data_element_to_map_without_default_initialization(
+            index_name=index_name, key_value=key_value, value=value, field_path_elements=field_path_elements
+        )
         if response is None:
             # If the response is None, it means that one of the path of the target path has not been found and need to be initialized.
             print(message_with_vars(
@@ -429,8 +459,9 @@ class DynamoDbCoreAdapter:
                 vars_dict={'index_name': index_name, 'key_value': key_value, 'field_path_elements': field_path_elements}
             ))
             return self.initialize_all_elements_in_map_target(
-                index_name=index_name, key_value=key_value, field_path_elements=field_path_elements,
-                last_item_custom_overriding_init_value=last_item_custom_overriding_init_value
+                index_name=index_name, key_value=key_value,
+                field_path_elements=field_path_elements,
+                last_item_custom_overriding_init_value=value
             )
         return response
 
@@ -442,9 +473,11 @@ class DynamoDbCoreAdapter:
             # target path has not been found and need to be initialized.
             last_response: Optional[Response] = None
             for i_setter, current_setter in enumerate(setters):
+                # todo: group fields initialization in single request
                 last_response = self.initialize_all_elements_in_map_target(
                     index_name=index_name, key_value=key_value,
-                    field_path_elements=current_setter.field_path_elements
+                    field_path_elements=current_setter.field_path_elements,
+                    last_item_custom_overriding_init_value=current_setter.value_to_set
                 )
                 if last_response is None:
                     print(message_with_vars(
@@ -582,7 +615,7 @@ class DynamoDbCoreAdapter:
             print("More than one item has been found. Returning first item.")
             return response.items[0]
 
-    def _get_or_query_single_item(self, index_name: str, key_value: str, fields_paths_elements: List[List[DatabasePathElement]]) -> Optional[dict]:
+    def get_or_query_single_item(self, index_name: str, key_value: str, fields_paths_elements: List[List[DatabasePathElement]]) -> Optional[dict]:
         if self.primary_index.hash_key_name == index_name:
             response_item: Optional[dict] = self.get_item_by_primary_key(
                 index_name=index_name, key_value=key_value, fields_paths_elements=fields_paths_elements
@@ -642,7 +675,7 @@ class DynamoDbCoreAdapter:
             num_keys_to_navigation_into: int
     ) -> Optional[any]:
 
-        response_item = self._get_or_query_single_item(
+        response_item = self.get_or_query_single_item(
             index_name=index_name, key_value=key_value,
             fields_paths_elements=[field_path_elements]
         )
@@ -667,10 +700,10 @@ class DynamoDbCoreAdapter:
 
     def get_data_from_multiple_fields_in_path_target(
             self, key_value: str, fields_paths_elements: Dict[str, List[DatabasePathElement]],
-            num_keys_to_stop_at_before_reaching_end_of_item: int, index_name: Optional[str] = None
-    ) -> Optional[Any]:
+            num_keys_to_stop_at_before_reaching_end_of_item: int, index_name: Optional[str] = None, metadata: bool = False
+    ) -> Optional[Dict[str, Any]]:
 
-        response_item = self._get_or_query_single_item(
+        response_item = self.get_or_query_single_item(
             index_name=index_name, key_value=key_value,
             fields_paths_elements=list(fields_paths_elements.values())
         )
@@ -704,22 +737,36 @@ class DynamoDbCoreAdapter:
                                 # and then we will return the response_item, so we will return None.
                                 break
 
-                        output_dict[path_elements_key] = current_navigated_response_item
+                        if metadata is not True:
+                            output_dict[path_elements_key] = current_navigated_response_item
+                        else:
+                            output_dict[path_elements_key] = {
+                                'value': current_navigated_response_item,
+                                'field_path_elements': path_elements_item
+                            }
             return output_dict
         return None
 
-    def get_values_in_multiple_path_target(self, index_name: str, key_value: str, fields_paths_elements: Dict[str, List[DatabasePathElement]]):
+    def get_values_in_multiple_path_target(
+            self, index_name: str, key_value: str,
+            fields_paths_elements: Dict[str, List[DatabasePathElement]],
+            metadata: bool = False
+    ):
         return self.get_data_from_multiple_fields_in_path_target(
             index_name=index_name, key_value=key_value,
             fields_paths_elements=fields_paths_elements,
-            num_keys_to_stop_at_before_reaching_end_of_item=0
+            num_keys_to_stop_at_before_reaching_end_of_item=0, metadata=metadata
         )
 
-    def get_items_in_multiple_path_target(self, index_name: str, key_value: str, fields_paths_elements: Dict[str, List[DatabasePathElement]]):
+    def get_items_in_multiple_path_target(
+            self, index_name: str, key_value: str,
+            fields_paths_elements: Dict[str, List[DatabasePathElement]],
+            metadata: bool = False
+    ):
         return self.get_data_from_multiple_fields_in_path_target(
             index_name=index_name, key_value=key_value,
             fields_paths_elements=fields_paths_elements,
-            num_keys_to_stop_at_before_reaching_end_of_item=1
+            num_keys_to_stop_at_before_reaching_end_of_item=1, metadata=metadata
         )
 
     @staticmethod
