@@ -6,8 +6,8 @@ from StructNoSQL.practical_logger import message_with_vars
 from StructNoSQL.query import Query
 
 
-FIELD_NAME_RESTRICTED_CHARS_LIST = ['[', ']', '{', '}']
-FIELD_NAME_RESTRICTED_CHARS_EXPRESSION = r'(\[|\]|\{|\})'
+FIELD_NAME_RESTRICTED_CHARS_LIST = ['[', ']', '{', '}', '(', ')' '|']
+FIELD_NAME_RESTRICTED_CHARS_EXPRESSION = r'(\[|\]|\{|\}|\(|\)|\|)'
 
 
 def _raise_if_field_name_is_invalid(field_name: str):
@@ -291,7 +291,7 @@ class MapItem(BaseField):
         super().__init__(name=None, field_type=field_type, custom_default_value=BaseItem.instantiate_default_value_type(field_type))
         self.map_model = model_type
 
-        from StructNoSQL.table import make_dict_key_var_name, try_to_get_primitive_default_type_of_item
+        from StructNoSQL.tables.base_table import make_dict_key_var_name, try_to_get_primitive_default_type_of_item
         element_key = make_dict_key_var_name(parent_field.key_name)
         default_type = try_to_get_primitive_default_type_of_item(parent_field.items_excepted_type)
         database_path_element = DatabasePathElement(element_key=element_key, default_type=default_type)
